@@ -6,33 +6,33 @@
 from colorama import Fore, Style
 
 
-def _wrap_color(text, color):
+def _wrap_color(text: str, color: str) -> str:
     return "{}{}{}".format(color, text, Fore.RESET)
 
 
-def _wrap_style(text, style):
+def _wrap_style(text: str, style: str) -> str:
     return "{}{}{}".format(style, text, Style.RESET_ALL)
 
 
-def red(text):
+def red(text: str) -> str:
     return _wrap_color(text, Fore.RED)
 
 
-def green(text):
+def green(text: str) -> str:
     return _wrap_color(text, Fore.GREEN)
 
 
-def yellow(text):
+def yellow(text: str) -> str:
     return _wrap_color(text, Fore.YELLOW)
 
 
-def cyan(text):
+def cyan(text: str) -> str:
     return _wrap_color(text, Fore.CYAN)
 
 
-def white(text):
+def white(text: str) -> str:
     return _wrap_color(text, Fore.WHITE)
 
 
-def bright(text):
+def bright(text: str) -> str:
     return _wrap_style(text, Style.BRIGHT)
