@@ -1,14 +1,12 @@
-# encoding: utf-8
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import absolute_import
 
-from enum import Enum
+from enum import Enum, unique
 
 
+@unique
 class Context(Enum):
     DUP_DATABASE = 1
     CONVERT_CONFIG = 5
@@ -22,14 +20,7 @@ class Context(Enum):
     SYMBOL_REPLACE_VALUE = 60
 
 
-class ExitCode(object):
-    SUCCESS = 0
-    FAILED_LOADER_NOT_FOUND = 1
-    FAILED_CONVERT = 2
-    FAILED_HTTP = 3
-    NO_INPUT = 10
-
-
+@unique
 class DupDatabase(Enum):
     OVERWRITE = 1
     APPEND = 2
