@@ -10,7 +10,7 @@ from ._base import SourceInfo, TableConverter
 
 
 class GoogleSheetsConverter(TableConverter):
-    def convert(self, credentials, title):
+    def convert(self, credentials, title: str) -> None:
         logger = self._logger
         result_counter = self._result_counter
         source_id = self._fetch_next_source_id()
@@ -53,3 +53,12 @@ class GoogleSheetsConverter(TableConverter):
         except ptr.APIError as e:
             logger.error(msgfy.to_error_message(e))
             result_counter.inc_fail()
+        except ImportError as e:
+            logger.error(
+                "{}: try to install dependencies with 'pip install sqlitebiter[gs]'".format(
+                    msgfy.to_error_message(e)
+                )
+            )
+        except OverflowError as e:
+            logger.error("{}: {}".format(title, e))
+            result_counter.inc_fail()
