@@ -1,19 +1,17 @@
-# encoding: utf-8
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import print_function
 
 import pytest
 from click.testing import CliRunner
 from pytablereader import SqliteFileLoader
 from simplesqlite import SimpleSQLite
-from sqlitebiter._enum import ExitCode
+from tabledata import TableData
+
+from sqlitebiter._const import ExitCode
 from sqlitebiter.sqlitebiter import cmd
 from sqlitebiter.subcommand._base import SourceInfo
-from tabledata import TableData
 
 from .common import print_traceback
 
@@ -46,7 +44,7 @@ def con_b0():
     return con
 
 
-class Test_sqlitebiter_file_sqlite_merge(object):
+class Test_sqlitebiter_file_sqlite_merge:
     def test_normal_same_table(self, con_a0, con_a1):
         out_db_path = "test.sqlite"
         runner = CliRunner()
