@@ -1,14 +1,13 @@
-# encoding: utf-8
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
 import pytest
+
 from sqlitebiter._ipynb_converter import is_ipynb_file_path, is_ipynb_url
 
 
-class Test_is_ipynb_file_path(object):
+class Test_is_ipynb_file_path:
     @pytest.mark.parametrize(
         ["value", "expected"],
         [
@@ -28,7 +27,7 @@ class Test_is_ipynb_file_path(object):
         assert is_ipynb_file_path(value) == expected
 
 
-class Test_is_ipynb_url(object):
+class Test_is_ipynb_url:
     @pytest.mark.parametrize(
         ["value", "expected"],
         [
